from distutils.core import setup

setup(
    name='Syxdemo',
    version='0.2',
    py_modules=['Syxdemo'],
    author='Runtian',
    author_email='runtian@amaresun.com',
    long_description_content_type='量化模型工具',
    url='https://github.com/RomanceCode/Syxdemo'
    )





